@@ -1,5 +1,5 @@
 package Task::MemManager::Device;
-$Task::MemManager::Device::VERSION = '0.01';
+$Task::MemManager::Device::VERSION = '0.02';
 use strict;
 use warnings;
 use Module::Find;
@@ -39,7 +39,7 @@ sub import {
 ## Switch to Task::MemManager namespace, since we are extending it
 
 package Task::MemManager;
-$Task::MemManager::VERSION = '0.01';
+$Task::MemManager::VERSION = '0.02';
 use feature 'refaliasing';
 no warnings 'experimental::refaliasing';
 no warnings 'redefine';    # to avoid warnings about DESTROY redefinition
@@ -331,7 +331,7 @@ Task::MemManager::Device - Device-specific memory management extensions for Task
 
 =head1 VERSION
 
-version 0.01
+version 0.02
 
 =head1 SYNOPSIS
 
@@ -557,13 +557,24 @@ The module supports device-specific compilation options for optimal performance:
 
 =head1 EXAMPLES
 
+Example 1 is a complete working example demonstrating basic GPU memory mapping,
+computation, and retrieval of results. Example 2 shows how to allocate GPU memory without initial data copy. Example 3 illustrates combining device management with PDL views for seamless integration with Perl Data Language.
 =head2 Example 1: Basic GPU Memory Mapping
 
 This example demonstrates the fundamental pattern of mapping memory to GPU,
 performing computations, and retrieving results.
 
     use Task::MemManager::Device;
-    use Inline C => Config => /* your OpenMP-enabled compiler flags */;
+    use Inline (
+    C => Config => ccflags => "-fno-stack-protector -fcf-protection=none "
+      . " -fopenmp  -Iinclude -std=c11 -fPIC "
+      . " -Wall -Wextra -Wno-unused-function -Wno-unused-variable"
+      . " -Wno-unused-but-set-variable ",
+    lddlflags => join( q{ }, $Config::Config{lddlflags}, q{-fopenmp} ),
+    ccflagsex => " -fopenmp ",
+    libs      => q{ -lm -foffload=-lm },
+    optimize  => "-O3 -march=native",
+    ); # replace with your OpenMP's device flags
     use Inline C => 'DATA';
     
     my $buffer_length = 250000;
@@ -578,10 +589,12 @@ performing computations, and retrieving results.
     # Update results back to CPU
     $buffer->device_movement(action => 'update', direction => 'from');
     
-    # Verify results
+    # Verify results by printing some values
     my @values = unpack("f*", $buffer->extract_buffer_region(0, 
                         $buffer->get_buffer_size - 1));
     
+    print "First 10 values: ", join(", ", @values[0..9]), "\n";
+    print "Last 10 values: ", join(", ", @values[-10..-1]), "\n";
     # Exit GPU mapping
     $buffer->device_movement(action => 'exit', direction => 'from');
     
@@ -603,6 +616,7 @@ performing computations, and retrieving results.
 When you want to allocate GPU memory but don't need to copy initial data
 (e.g., for output-only computations):
 
+    # look at Example 1 for the use statements and Inline C setup
     my $buffer = Task::MemManager->new(1000000, 4);
     
     # Allocate GPU memory without copying
@@ -636,6 +650,17 @@ Perl Data Language:
         Allocator => 'CMalloc',
         View      => 'PDL',
         Device    => 'NVIDIA_GPU';
+    use Inline (
+    C => Config => ccflags => "-fno-stack-protector -fcf-protection=none "
+      . " -fopenmp  -Iinclude -std=c11 -fPIC "
+      . " -Wall -Wextra -Wno-unused-function -Wno-unused-variable"
+      . " -Wno-unused-but-set-variable ",
+    lddlflags => join( q{ }, $Config::Config{lddlflags}, q{-fopenmp} ),
+    ccflagsex => " -fopenmp ",
+    libs      => q{ -lm -foffload=-lm },
+    optimize  => "-O3 -march=native",
+    ); # replace with your OpenMP's device flags
+    use Inline C => 'DATA';  
     
     my $buffer_length = 1000;
     my $buffer = Task::MemManager->new($buffer_length, 4, 
@@ -664,7 +689,7 @@ Perl Data Language:
     for my $i (0 .. $#values) {
         die "Mismatch!" unless $values[$i] == $original[$i] * 2.0;
     }
-    
+
     __DATA__
     __C__
     #include "omp.h"
@@ -680,7 +705,7 @@ Perl Data Language:
 
 =head2 Example 4: Multiple Device Management
 
-Managing multiple buffers across different devices:
+Managing multiple buffers across different devices (code snippet):
 
     # Create multiple buffers
     my $buf1 = Task::MemManager->new(1000, 4);
@@ -823,7 +848,7 @@ For NVIDIA GPU support, you need:
 
 =item * Provide device property queries (memory available, etc.)
 
-=item * Add support for CUDA/HIP native APIs as alternative to OpenMP
+=item * Add support for interfacing to other parallel programming models (e.g., CUDA, HIP) using OpenMP's interoperability features
 
 =item * Implement automatic workload distribution across multiple devices
 
@@ -858,6 +883,9 @@ For NVIDIA GPU support, you need:
 =head1 AUTHOR
 
 Christos Argyropoulos, C<< <chrisarg at cpan.org> >>
+Initial documentation was created by Claude Sonnet 4.5 after providing the 
+human generated test files for the module and the documentation in the 
+MemManager distribution as context. 
 
 =head1 COPYRIGHT AND LICENSE
 
